@@ -52,16 +52,15 @@ for dir_path in dir_list:
     dir_name = dir_path.name
     source = str(data_output_dir_path / dir_name)
     dummy_path = str(data_output_dir_path / dir_name / 'dummy.json')
-    with open(dummy_path, 'w') as f:
-        json.dump({}, f, indent=2)
-
-    Dataset.File.upload_directory(
-        src_dir=source, target=DataPath(dstore, str(Path(save_datastore_path) / dir_name)), pattern="*",
-        show_progress=True,
-        overwrite=True
-    )
 
     subdir_list = [p for p in Path(source).iterdir() if p.is_dir()]
+    subfiles_list = [p for p in Path(source).iterdir() if p.is_file()]
+    if len(subfiles_list) <= 0 < len(subdir_list):
+        Dataset.File.upload_directory(
+            src_dir=source, target=DataPath(dstore, str(Path(save_datastore_path) / dir_name)), pattern="*",
+            show_progress=True,
+            overwrite=True
+        )
 
     for subdir_path in subdir_list:
         subdirname = subdir_path.name
